@@ -28,7 +28,8 @@ setClass(Class = "gergm",
            print_output = "logical",
            is_correlation_network = "logical",
            undirected_network = "logical",
-           simulation_only = "logical"
+           simulation_only = "logical",
+           thresholds = "numeric"
          ),
          validity = function(object) {
            if (!"matrix" %in% class(object@network) & is.null(object@network)
